package VMOMI::HostHardwareElementStatus;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
